[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - fedex.base_service.FedexBaseServiceException: Exception: Serves as the base exception that other service-related exception objects are sub-classed from.
        - fedex.base_service.FedexError: Exception: These are generally problems with the client-provided data.
          - fedex.services.package_movement.FedexInvalidPostalCodeFormat: Exception: Sent when the postal code is invalid
          - fedex.services.track_service.FedexInvalidTrackingNumber: Exception: Sent when a bad tracking number is provided.
          - fedex.services.package_movement.FedexPostalCodeNotFound: Exception: Sent when the postalcode is missing.
        - fedex.base_service.FedexFailure: Exception: The request could not be handled at this time.
        - fedex.base_service.SchemaValidationError: Exception: There is probably a problem in the data you provided.
  - fedex.printers.unix.DirectDevicePrinter: This class pipes the label data directly through a /dev/* entry.
  - fedex.base_service.FedexBaseService: This class is the master class for all Fedex request objects.
    - fedex.services.address_validation_service.FedexAddressValidationRequest: This class allows you validate anywhere from one to a hundred addresses in one go.
    - fedex.services.ship_service.FedexDeleteShipmentRequest: This class allows you to delete a shipment, given a tracking number.
    - fedex.services.ship_service.FedexProcessShipmentRequest: This class allows you to process (create) a new FedEx shipment.
    - fedex.services.rate_service.FedexRateServiceRequest: This class allows you to get the shipping charges for a particular address.
    - fedex.services.track_service.FedexTrackRequest: This class allows you to track shipments by providing a tracking number or other identifying features.
    - fedex.services.package_movement.PostalCodeInquiryRequest: The postal code inquiry enables customers to validate postal codes and service commitments.
  - fedex.config.FedexConfig: Base configuration class that is used for the different Fedex SOAP calls.